% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions.r
\name{POWER}
\alias{POWER}
\title{Exact Power of Test for Selected Sample Sizes.}
\usage{
POWER(
  n0,
  n1,
  alpha = 0.05,
  delta = 0,
  psi = 0,
  type = "lr",
  p0 = NULL,
  obj = NULL
)
}
\arguments{
\item{n0}{control sample size}

\item{n1}{treatment sample size}

\item{alpha}{value of nominal size of test}

\item{delta}{value of clinically relevant difference}

\item{psi}{null value of risk difference p1-p0}

\item{type}{either "lr" for approximate or "elr" for quasi-exact test}

\item{p0}{baseline probability. If missing, a grid of values is created for
plotting. A scalar value can also be supplied.}

\item{obj}{Optional objet with all possible p-values. Must be a list with
components y0, y1, P (typically output of lr.rd or ESTEP.rd). If not supplied
then object is generated from n0, n1 and psi.}
}
\value{
list with component x (containing values of baseline probability)
and component y (containing corresponding exact powers)
}
\description{
Once sample sizes n0, n1 have been realised, this function computed the
exact probability of rejecting the null as a function of baseline
probability.
}
\details{
p0 values must be between max(0,-delta) and min(1,1-delta)
}
\examples{

# Typical usage
#       POWER(n0=65,n1=82,psi=0,type="lr") # Exact size of approximate lr test
#       POWER(n0=65,n1=82,psi=0,type="elr",delta=.2) # Exact power of quasi exact test
#
# Functions lr.rd, ESTEP.rd are not exported so output has been made part of package.
load(system.file('files', "lr.stats.Rdata", package = 'exact.n'))
# Created by lr.stats=lr.rd(n0=65,n1=82,psi=0) # Object contains all approximate lr p-values
load(system.file('files', "elr.stats.Rdata", package = 'exact.n'))
# Created by elr.stats=ESTEP.rd(n0=65,n1=82,psi=0) # Object contains all exact p-values
#
par(mfrow=c(1,2))
# When delta=0 this gives type 1 error. The first plot is for the approximate
# lr based p-value, the second is for the quasi-exact e-p-value (alpha=0.05)
plot(POWER(obj=lr.stats,alpha=0.05,delta=0),type="l",
     xlab=expression("p"[0]),ylab="exact size")
abline(h=.05,lty=2)
plot(POWER(obj=elr.stats,alpha=0.05,delta=0),type="l",
     xlab=expression("p"[0]),ylab="exact size")
abline(h=.05,lty=2)
#
# For these sample sizes, it is hard to detect a difference of 0.1 (see red).
plot(POWER(obj=lr.stats,alpha=0.05,delta=0.1),type="l",
     xlab=expression("p"[0]),ylab="exact power")
lines(POWER(obj=lr.stats,alpha=0.05,delta=0.12))
lines(POWER(obj=lr.stats,alpha=0.05,delta=0.14))
lines(POWER(obj=lr.stats,alpha=0.05,delta=0.16))
lines(POWER(obj=lr.stats,alpha=0.05,delta=0.18))
lines(POWER(obj=lr.stats,alpha=0.05,delta=0.2))
lines(POWER(obj=lr.stats,alpha=0.05,delta=0.1),col="red")
#
load(system.file('files', "elr10.stats.Rdata", package = 'exact.n'))
# Created by elr10.stats=ESTEP.rd(n0=65,n1=82,psi=0.1)
# Object contains all exact p-values for testing if p1-p0>0.1
#
plot(c(0,.9),c(0,1),type="n",
     xlab=expression("p"[0]),ylab="Pr(reject null)")
lines(POWER(obj=elr10.stats,alpha=0.05,delta=0.1)) # The exact size of the test since delta=psi.
abline(h=0.05,lty=2)
lines(POWER(obj=elr10.stats,alpha=0.05,delta=0.25))
title(main="Exact size and power of test of psi>0.1")
#

}
\references{
C.J. Lloyd & R. Ripamonti (2021) A comprehensive open-source
library for exact required sample size in binary clinical trials.
Contemporary Clinical Trials 107. \doi{10.1016/j.cct.2021.106491}
}
\author{
Chris J. Lloyd
}
